@@ -22,7 +22,7 @@ __PACKAGE__->belongs_to(
   { 'foreign.one_id' => 'self.one_id' }
 );
 
-__PACKAGE__->accept_nested_for('one', {update_only=>1});
+#__PACKAGE__->accept_nested_for('one', {update_only=>1});
 #__PACKAGE__->validates(one => ( result=>+{validations=>1} ));
 
 1;
